.. ocrmypdf documentation master file, created by
   sphinx-quickstart on Sun Sep  4 14:29:43 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

OCRmyPDF documentation
======================

OCRmyPDF adds an OCR text layer to scanned PDF files, allowing them to
be searched.

PDF is the best format for storing and exchanging scanned documents.  Unfortunately, PDFs can be difficult to modify. OCRmyPDF makes it easy to apply image processing and OCR to existing PDFs.

.. toctree::
   :maxdepth: 1

   introduction
   release_notes
   installation
   languages
   jbig2

.. toctree::
   :caption: Usage
   :maxdepth: 2

   cookbook
   advanced
   batch
   security
   errors


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
